Learn R Programming

irtplay (version 1.6.5)

run_flexmirt: Run flexMIRT through R

Description

This function implements flexMIRT (Cai, 2017) to run a model specified in the syntax file of flexMIRT (i.e., *.flexmirt) through R. To run this function, flexMIRT software must be installed in advance. This function will be useful especially when conducting a simulation study using flexMIRT.

Usage

run_flexmirt(file.syntax, dir.flex = NULL, show.output.on.console = FALSE, ...)

Value

output files of flexMIRT

Arguments

file.syntax

A single string or vector containing the file path(s) of a flexmirt syntax file(s) to be run. An example is “C:/Users/Data/irtmodel.flexmirt".

dir.flex

A path of directory where flexMIRT is installed. The path may include a folder name with "flexMIRT" (e.g, flexMIRT3, flexMIRT 3.6). If NULL, a path where flexMIRT is installed will be searched in "C:/Program Files" and it will be used as a default path (e.g., "C:/Program Files/flexMIRT3", "C:/Program Files/flexMIRT 3.6").

show.output.on.console

A logical value to indicate whether to capture the output of the command and show it on the R console. Default is FALSE. See system.

...

Further arguments passed from the function system.

Author

Hwanggyu Lim hglim83@gmail.com

Details

When a path of directory where flexMIRT (with a version < 3.6) is installed is provided in the argument dir.flex, the directory must include following six file of

  • WinFlexMIRT.exe

  • FlexMIRT_x64.exe

  • FlexMIRT_x86.exe

  • vpg.dll

  • vpg.licensing.client.dll

  • vpg.licensing.dll

When a path of directory where flexMIRT (with a version >= 3.6) is installed is provided in the argument dir.flex, the directory must include following six files of

  • WinFlexMIRT.exe

  • vpg.dll

  • vpg.licensing.client.dll

  • vpg.licensing.dll

  • VPGLicenseClientNet.dll

and an additional directory of "Resources" that contains two files which are

  • flexMIRT_x64_AVX.exe

  • flexMIRT_x86_AVX.exe

References

Cai, L. (2017). flexMIRT 3.5 Flexible multilevel multidimensional item analysis and test scoring [Computer software]. Chapel Hill, NC: Vector Psychometric Group.

Examples

Run this code

# Emxaples below will run when flexMIRT software is installed
# in a default path of "C:/Program Files/flexMIRT3".
# Otherwise provide a path where flexMIRT software is installed
# in the argument 'dir.flex'.

if (FALSE) {
# (1) run a single syntax file
# import an example of flexMIRT syntax file to run the item parameter estimation of IRT 3PL model
file.syntax <- system.file("extdata", "2PLM_example.flexmirt", package = "irtplay")

# run flexMIRT to estimate the item parameters of IRT 3PL model
run_flexmirt(file.syntax=file.syntax, dir.flex=NULL, show.output=TRUE)

# check the output file
out.file <- system.file("extdata", "2PLM_example-prm.txt", package = "irtplay")
bring.flexmirt(out.file, type="par")

# (2) run multiple syntax files
# import two examples of flexMIRT syntax files
file.syntax1 <- system.file("extdata", "2PLM_example.flexmirt", package = "irtplay")
file.syntax2 <- system.file("extdata", "3PLM_example.flexmirt", package = "irtplay")

# run flexMIRT to estimate the item parameters
run_flexmirt(file.syntax=c(file.syntax1, file.syntax2), dir.flex=NULL, show.output=FALSE)

# check the output file
out.file1 <- system.file("extdata", "2PLM_example-prm.txt", package = "irtplay")
out.file2 <- system.file("extdata", "3PLM_example-prm.txt", package = "irtplay")
bring.flexmirt(out.file1, type="par")
bring.flexmirt(out.file2, type="par")
}


Run the code above in your browser using DataLab